@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 use base qw/Class::Accessor::Fast/;
 
@@ -16,7 +16,7 @@ use Shipwright::Backend;
 use Shipwright::Source;
 use Shipwright::Build;
 use File::Temp qw/tempdir/;
-use File::Spec::Functions qw/catfile catdir/;
+use File::Spec::Functions qw/catfile/;
 
 sub new {
     my $class = shift;
@@ -185,9 +185,9 @@ Under scripts/cpan-Acme-Hello there are two files: 'build' and 'require.yml'.
 =head4 build
 
 configure: %%PERL%% Build.PL --install_base=%%INSTALL_BASE%%
-make: ./Build
-test: ./Build test
-install: ./Build install
+make: %%PERL%% Build
+test: %%PERL%% Build test
+install: %%PERL%% Build install
 clean: %%PERL%% Build realclean
 
 Each line is of `type: command' format, and the command is executed line by
