@@ -3,7 +3,7 @@ package Shipwright::Backend::SVK;
 use warnings;
 use strict;
 use Carp;
-use File::Spec::Functions qw/catfile catdir/;
+use File::Spec::Functions qw/catfile/;
 use Shipwright::Util;
 use File::Temp qw/tempdir/;
 use File::Copy qw/copy/;
@@ -70,8 +70,6 @@ sub _cmd {
     elsif ( $type eq 'export' ) {
         $cmd =
           [ 'svk', 'checkout', $self->repository . $args{path}, $args{target} ];
-
-        #            $cmd = [ 'svk', 'checkout', '-d', $args{target} ];
     }
     elsif ( $type eq 'list' ) {
         $cmd = [ 'svk', 'list', $self->repository . $args{path} ];
@@ -81,14 +79,14 @@ sub _cmd {
             $cmd = [
                 'svk',         'import',
                 $args{source}, $self->repository,
-                '-m',          q{'} . $args{comment} . q{'},
+                '-m',          $args{comment},
             ];
         }
         elsif ( $args{_extra_tests} ) {
             $cmd = [
                 'svk',         'import',
                 $args{source}, $self->repository . '/t/extra',
-                '-m',          q{'} . $args{comment} . q{'},
+                '-m',          $args{comment},
             ];
         }
         else {
@@ -96,26 +94,26 @@ sub _cmd {
                 $cmd = [
                     'svk',       'import',
                     $script_dir, $self->repository . "/scripts/$args{name}/",
-                    '-m',        q{'} . $args{comment} . q{'},
+                    '-m',        $args{comment},
                 ];
             }
             else {
                 $cmd = [
                     'svk',         'import',
                     $args{source}, $self->repository . "/dists/$args{name}",
-                    '-m',          q{'} . $args{comment} . q{'},
+                    '-m',          $args{comment},
                 ];
             }
         }
     }
     elsif ( $type eq 'commit' ) {
         $cmd =
-          [ 'svk', 'commit', '-m', q{'} . $args{comment} . q{'}, $args{path} ];
+          [ 'svk', 'commit', '-m', $args{comment}, $args{path} ];
     }
     elsif ( $type eq 'delete' ) {
         $cmd = [
             'svk', 'delete', '-m',
-            q{'} . 'delete repository' . q{'},
+            'delete repository',
             $self->repository . $args{path},
         ];
     }
@@ -124,7 +122,7 @@ sub _cmd {
             'svk',
             'move',
             '-m',
-            q{'} . "move $args{path} to $args{new_path}" . q{'},
+            "move $args{path} to $args{new_path}",
             $self->repository . $args{path},
             $self->repository . $args{new_path}
         ];
