@@ -8,7 +8,7 @@ use base qw/Class::Accessor::Fast/;
 
 __PACKAGE__->mk_accessors(
     qw/install_base perl build_base skip_test commands log
-      skip only_test force order flags name only/
+      skip only_test force order flags name only make/
 );
 
 use File::Spec::Functions qw/catfile catdir splitdir/;
@@ -40,6 +40,7 @@ sub new {
 
     $self->name('vessel') unless $self->name;
     $self->skip( {} ) unless $self->skip;
+    $self->make('make') unless $self->make;
 
     unless ( $self->install_base ) {
 
@@ -50,20 +51,20 @@ sub new {
     no warnings 'uninitialized';
 
     $ENV{DYLD_LIBRARY_PATH} =
-      catfile( $self->install_base, 'lib' ) . ':' . $ENV{DYLD_LIBRARY_PATH};
+      catdir( $self->install_base, 'lib' ) . ':' . $ENV{DYLD_LIBRARY_PATH};
     $ENV{LD_LIBRARY_PATH} =
-      catfile( $self->install_base, 'lib' ) . ':' . $ENV{LD_LIBRARY_PATH};
+      catdir( $self->install_base, 'lib' ) . ':' . $ENV{LD_LIBRARY_PATH};
     $ENV{PERL5LIB} =
-        catfile( $self->install_base, 'lib', 'perl5', 'site_perl' ) . ':'
-      . catfile( $self->install_base, 'lib', 'perl5' ) . ':'
+        catdir( $self->install_base, 'lib', 'perl5', 'site_perl' ) . ':'
+      . catdir( $self->install_base, 'lib', 'perl5' ) . ':'
       . $ENV{PERL5LIB};
     $ENV{PATH} =
-        catfile( $self->install_base, 'bin' ) . ':'
-      . catfile( $self->install_base, 'sbin' ) . ':'
+        catdir( $self->install_base, 'bin' ) . ':'
+      . catdir( $self->install_base, 'sbin' ) . ':'
       . $ENV{PATH};
     $ENV{PERL_MM_USE_DEFAULT} = 1;
-    $ENV{LDFLAGS} .= ' -L' . catfile( $self->install_base, 'lib' );
-    $ENV{CFLAGS}  .= ' -I' . catfile( $self->install_base, 'include' );
+    $ENV{LDFLAGS} .= ' -L' . catdir( $self->install_base, 'lib' );
+    $ENV{CFLAGS}  .= ' -I' . catdir( $self->install_base, 'include' );
 
     require CPAN;
     require Module::Info;
@@ -104,7 +105,7 @@ sub run {
         $self->test;
     }
     else {
-        dircopy( 'etc', catfile( $self->install_base, 'etc' ) );
+        dircopy( 'etc', catdir( $self->install_base, 'etc' ) );
 
         my $installed_hash = {};
         $installed_file = catfile( $self->install_base, 'installed.yml' );
@@ -187,7 +188,7 @@ sub run {
             chdir $self->build_base;
         }
 
-        $self->_wrapper();
+        $self->_wrapper() unless $^O =~ /MSWin/;
 
         $self->log->info(
             "install finished. the dists are at " . $self->install_base );
@@ -203,7 +204,7 @@ sub _install {
     my $dir  = shift;
     my $ktf  = shift;
 
-    chdir catfile( 'dists', $dir );
+    chdir catdir( 'dists', $dir );
 
     if ( -e catfile( '..', '..', 'scripts', $dir, 'build.pl' ) ) {
         $self->log->info(
@@ -253,16 +254,18 @@ sub _install {
                         $self->log->error(
 "although tests failed, will install anyway since we have force arg\n"
                         );
+                        next;
                     }
                     ## no critic
                     elsif ( eval "$ktf->{$dir}" ) {
                         $self->log->error(
 "although tests failed, will install anyway since it's a known failure\n"
                         );
+                        next;
                     }
-                    next;
                 }
-                elsif ( $type ne 'clean' ) {
+
+                if ( $type ne 'clean' ) {
 
                     # clean is trivial, we'll just ignore if 'clean' fails
                     confess "build $dir $type part with failure.";
@@ -289,8 +292,8 @@ sub _wrapper {
         }
 
         my $dir = ( splitdir($File::Find::dir) )[-1];
-        mkdir catfile( $self->install_base,       "$dir-wrapped" )
-          unless -d catfile( $self->install_base, "$dir-wrapped" );
+        mkdir catdir( $self->install_base,       "$dir-wrapped" )
+          unless -d catdir( $self->install_base, "$dir-wrapped" );
 
         if ( -e catfile( $self->install_base, "$dir-wrapped", $file ) ) {
             $self->log->warn( 'found old '
@@ -320,7 +323,7 @@ sub _wrapper {
             }
         }
 
-        move( $file => catfile( $self->install_base, "$dir-wrapped" ) )
+        move( $file => catdir( $self->install_base, "$dir-wrapped" ) )
           or confess $!;
 
     # if we have this $type(e.g. perl) installed and have that specific wrapper,
@@ -341,7 +344,7 @@ sub _wrapper {
 
     my @dirs =
       grep { -d $_ }
-      map { catfile( $self->install_base, $_ ) } qw/bin sbin/;
+      map { catdir( $self->install_base, $_ ) } qw/bin sbin/;
     find( $sub, @dirs ) if @dirs;
 }
 
@@ -359,6 +362,7 @@ sub _substitute {
     $text =~ s/%%PERL%%/$perl/g;
     $text =~ s/%%PERL_ARCHNAME%%/$perl_archname/g;
     $text =~ s/%%INSTALL_BASE%%/$install_base/g;
+    $text =~ s/%%MAKE%%/$self->make/eg;
     return $text;
 }
 
